@@ -1,21 +1,11 @@
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, Iterable, TypeVar
+from typing import Awaitable, Callable, Iterable
 
+from aiohttp.typedefs import Middleware
+from aiohttp.web_middlewares import middleware
 from aiohttp.web_request import Request
 from aiohttp.web_response import StreamResponse
 
-if TYPE_CHECKING:
-    F = TypeVar("F", bound=Callable[..., Any])
-    middleware: Callable[[F], F]
-else:
-    try:
-        from aiohttp.web_middlewares import middleware
-    except ImportError:
-        # @middleware is deprecated and its behaviour is the default since aiohttp 4.0
-        # so if it doesn't exist anymore, define a no-op for forward compatibility.
-        middleware = lambda x: x  # noqa: E731
-
 Handler = Callable[[Request], Awaitable[StreamResponse]]
-Middleware = Callable[[Request, Handler], Awaitable[StreamResponse]]
 
 
 def cors(allow_headers: Iterable[str]) -> Middleware:
